certifi: Python package for providing Mozilla's CA Bundle
=========================================================

Description
-----------

Python package for providing Mozilla's CA Bundle.

License
-------

MPL-2.0

Upstream Contact
----------------

https://pypi.org/project/certifi/

